# pylint: skip-file
from .aesencryptionalgorithm import AESEncryptionAlgorithm
from .aeskeywrapalgorithm import AESKeyWrapAlgorithm
from .algorithm import Algorithm
from .ellipticcurvesigningalgorithm import EllipticCurveSigningAlgorithm
from .encryptionalgorithm import EncryptionAlgorithm
from .hmacsigningalgorithm import HMACSigningAlgorithm
from .rsaencryptionalgorithm import RSAEncryptionAlgorithm
from .rsasigningalgorithm import RSASigningAlgorithm
from .signingalgorithm import SigningAlgorithm


__all__ = [
    'Algorithm',
    'EllipticCurveSigningAlgorithm',
    'EncryptionAlgorithm',
    'RSASigningAlgorithm',
    'SigningAlgorithm',
]


Algorithm.add('RS256', RSASigningAlgorithm(algorithm='sha256', padding='PKCS1v15'))
Algorithm.add('RS384', RSASigningAlgorithm(algorithm='sha384', padding='PKCS1v15'))
Algorithm.add('RS512', RSASigningAlgorithm(algorithm='sha512', padding='PKCS1v15'))
Algorithm.add('PS256', RSASigningAlgorithm(algorithm='sha256', padding='PSS'))
Algorithm.add('PS384', RSASigningAlgorithm(algorithm='sha384', padding='PSS'))
Algorithm.add('PS512', RSASigningAlgorithm(algorithm='sha512', padding='PSS'))
Algorithm.add('ES256', EllipticCurveSigningAlgorithm(algorithm='sha256'))
Algorithm.add('ES384', EllipticCurveSigningAlgorithm(algorithm='sha384'))
Algorithm.add('ES512', EllipticCurveSigningAlgorithm(algorithm='sha512'))
Algorithm.add('ES256K', EllipticCurveSigningAlgorithm(algorithm='sha256'))
Algorithm.add('HS256', HMACSigningAlgorithm(algorithm='sha256'))
Algorithm.add('HS384', HMACSigningAlgorithm(algorithm='sha384'))
Algorithm.add('HS512', HMACSigningAlgorithm(algorithm='sha512'))
Algorithm.add('EdDSA', SigningAlgorithm())
Algorithm.add('RSA1_5', RSAEncryptionAlgorithm(padding='PKCS1v15'))
Algorithm.add('RSA-OAEP', RSAEncryptionAlgorithm(padding='OAEP', algorithm='sha1'))
Algorithm.add('RSA-OAEP-256', RSAEncryptionAlgorithm(padding='OAEP', algorithm='sha256'))
Algorithm.add('RSA-OAEP-384', RSAEncryptionAlgorithm(padding='OAEP', algorithm='sha384'))
Algorithm.add('RSA-OAEP-512', RSAEncryptionAlgorithm(padding='OAEP', algorithm='sha512'))
Algorithm.add('A128KW', AESKeyWrapAlgorithm())
Algorithm.add('A192KW', AESKeyWrapAlgorithm())
Algorithm.add('A256KW', AESKeyWrapAlgorithm())
Algorithm.add('A128GCM', AESEncryptionAlgorithm(mode='GCM'))
Algorithm.add('A192GCM', AESEncryptionAlgorithm(mode='GCM'))
Algorithm.add('A256GCM', AESEncryptionAlgorithm(mode='GCM'))
Algorithm.add('A128GCMKW', AESEncryptionAlgorithm(mode='GCM'))
Algorithm.add('A192GCMKW', AESEncryptionAlgorithm(mode='GCM'))
Algorithm.add('A256GCMKW', AESEncryptionAlgorithm(mode='GCM'))
Algorithm.add('A128CBC', AESEncryptionAlgorithm(mode='CBC', iv=16))
Algorithm.add('A192CBC', AESEncryptionAlgorithm(mode='CBC', iv=16))
Algorithm.add('A256CBC', AESEncryptionAlgorithm(mode='CBC', iv=16))


def get(name: str) -> Algorithm:
    """Return a :class:`Algorithm` implementation that implements the
    signing or encryption algorithm specified by the `name` parameter.
    """
    return Algorithm.get(name)