"""Declares :class:`AESEncryptionAlgorithm`."""
import typing

from cryptography.hazmat.primitives.ciphers.algorithms import AES
from cryptography.hazmat.primitives import padding

from .. import ops
from .encryptionalgorithm import EncryptionAlgorithm


class AESEncryptionAlgorithm(EncryptionAlgorithm):
    __module__: str = 'ckms.algorithms'

    @property
    def padding(self) -> padding.PKCS7:
        return padding.PKCS7(AES.block_size)

    def __init__(self, mode: str, tag=16, iv=12, nonce=12):
        super().__init__()
        self.mode = mode
        self.tag = tag
        self.iv = iv
        self.nonce = nonce

    def get_encryption_parameters(
        self,
        key: 'KeySpecification',
        data: typing.Union[ops.Ciphertext, ops.Plaintext]
    ) -> dict:
        """Hook to provide parameters to :class:`ckms.ops.EncryptOperation`."""
        return {
            'iv': self.iv,
            'mode': self.mode,
            'tag': self.tag,
            'padding': self.padding
        }