"""Declares :class:`Algorithm`."""
from cryptography.hazmat.primitives import hashes


ALGORITHMS = {
    'sha1'  : hashes.SHA1,
    'sha256': hashes.SHA256,
    'sha384': hashes.SHA384,
    'sha512': hashes.SHA512,
}


class Algorithm:
    """The base class for all signing and encryption algorithms."""
    __module__: str = 'ckms.algorithms'
    _registry = {}

    @staticmethod
    def get(name: str) -> 'Algorithm':
        """Return a :class:`Algorithm` implementation that implements the
        signing or encryption algorithm specified by the `name` parameter.
        """
        return Algorithm._registry[name]        

    @staticmethod
    def add(name: str, algorithm: 'Algorithm'):
        """Add a named signing or encryption algorithm to the register."""
        Algorithm._registry[name] = algorithm

    @property
    def algorithm(self) -> hashes.Hash:
        return ALGORITHMS[self._algorithm]() if self._algorithm else None