"""Declares :class:`RSAEncryptionAlgorithm`."""
import typing

from .. import ops
from .encryptionalgorithm import EncryptionAlgorithm
from .rsamixin import RSAMixin


class RSAEncryptionAlgorithm(EncryptionAlgorithm, RSAMixin):
    __module__: str = 'ckms.algorithms'

    def __init__(
        self,
        padding: typing.Literal['PKCS1v15', 'PSS', 'OAEP'],
        algorithm: typing.Literal['sha1', 'sha256', 'sha384', 'sha512'] = None
    ):
        super().__init__(wrap=False)
        self._algorithm = algorithm
        self._padding = padding


    def get_encryption_parameters(
        self,
        key: 'KeySpecification',
        data: typing.Union[ops.Digest, ops.Message]
    ) -> dict:
        """Hook to provide parameters to :class:`ckms.ops.EncryptOperation`."""
        return {
            'padding': self.get_padding(self.algorithm, self._padding)
        }