"""Declares :class:`RSASigningAlgorithm`."""
import typing

from .. import ops
from .rsamixin import RSAMixin
from .signingalgorithm import SigningAlgorithm


class RSASigningAlgorithm(SigningAlgorithm, RSAMixin):
    __module__: str = 'ckms.algorithms'

    def __init__(
        self,
        algorithm: typing.Literal['sha1', 'sha256', 'sha384', 'sha512'],
        padding: typing.Literal['PKCS1v15', 'PSS']
    ):
        self._algorithm = algorithm
        self._padding = padding

    def get_signing_parameters(
        self,
        key: 'KeySpecification',
        data: typing.Union[ops.Digest, ops.Message]
    ) -> dict:
        """Hook to provide parameters to :class:`ckms.ops.SignOperation`."""
        return {
            'algorithm': self.algorithm,
            'padding': self.get_padding(self.algorithm, self._padding)
        }