# Copyright 2022 Cochise Ruhulessin
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
from .keyinspector import KeyInspector
from .types import RemoteBlobParams as RemoteBlob
from .provider import Provider


__all__ = [
   'KeyInspector',
   'Provider',
   'RemoteBlob',
]


def provider(name: str) -> Provider:
    """Configure the provider with the given name and return the
    configured instance.
    """
    return Provider.get(name) # type: ignore


async def fetch(blob: RemoteBlob) -> bytes:
   """Fetches the content of the remote blob using the parameters
   specified. Return a byte-string holding the content.
   """
   provider = Provider.get(blob.provider)
   return await provider.fetch(blob) # type: ignore