"""Declares :class:`AudienceType`"""
import typing


VALID_TYPES = typing.Union[
    str,
    typing.Iterable[str]
]


class AudienceType(set):
    __module__: str = "ckms.jose"

    @classmethod
    def __get_validators__(
        cls
    ) -> typing.Generator[typing.Any, typing.Any, typing.Any]:
        yield cls.validate

    @classmethod
    def validate(cls,
        value: typing.Optional[VALID_TYPES]
    ) -> 'AudienceType':
        if isinstance(value, str):
            value = {value}
        if not all([isinstance(x, str) for x in value]): # type: ignore
            raise TypeError("Audience must be strings.")
        return cls(value or {})

    @classmethod
    def __modify_schema__(
        cls,
        field_schema: typing.Dict[str, typing.Any]
    ) -> None: # pragma: no cover
        field_schema.update(
            type="array",
            examples=[
                "https://oauth2.unimatrixapis.com",
                ["https://oauth2.unimatrixapis.com"]
            ]
        )