# pylint: skip-file
from cryptography.hazmat.primitives.asymmetric import ec
from cryptography.hazmat.primitives.asymmetric import ed448
from cryptography.hazmat.primitives.asymmetric import ed25519
from cryptography.hazmat.primitives.asymmetric import x448
from cryptography.hazmat.primitives.asymmetric import x25519
from cryptography.hazmat.primitives.asymmetric import rsa


CURVE_MAPPING = {
    "P-256": ec.SECP256R1,
    "P-384": ec.SECP384R1,
    "P-512": ec.SECP521R1,
    "P-256K": ec.SECP256K1,
    ec.SECP256R1.name: "P-256",
    ec.SECP384R1.name: "P-384",
    ec.SECP521R1.name: "P-512",
    ec.SECP256K1.name: "P-256K"
}

OKP_KEY_CLASSES = {
    "Ed448": ed448.Ed448PrivateKey,
    "Ed25519": ed25519.Ed25519PrivateKey,
    "X448": x448.X448PrivateKey,
    "X25519": x25519.X25519PrivateKey
}

KTY_SIG_ALGORITHMS = {
    ("RSA", None): {"RS256", "RS384", "RS512", "PS256", "PS384", "PS512"},
    ("EC", "P-256"): {"ES256"},
    ("EC", "P-384"): {"ES384"},
    ("EC", "P-512"): {"ES512"},
    ("EC", "P-256K"): {"ES256K"},
    ("OKP", None): {"EdDSA"},
    ("oct", None): {"HS256", "HS384", "HS512"}
}

KTY_ENC_ALG_ALGORITHMS = {
    ('RSA', None): {
        "RSA1_5",
        "RSA-OAEP",
        "RSA-OAEP-256",
        "RSA-OAEP-384",
        "RSA-OAEP-512",
    },
    "EC": {
        "ECDH-ES",
        "ECDH-ES+A128KW",
        "ECDH-ES+A192KW",
        "ECDH-ES+A256KW",
    },
    ('OKP', None): {
        "ECDH-ES",
        "ECDH-ES+A128KW",
        "ECDH-ES+A192KW",
        "ECDH-ES+A256KW",
    }
}