"""Declares :class:`HMACSecret`."""
import hmac


class HMACSecret:
    """Wraps a secret used to create HMAC signatures."""

    def __init__(self, secret: bytes):
        self._secret = secret

    def sign(self, data: bytes, algorithm: str) -> bytes:
        return hmac.digest(self._secret, data, algorithm)

    def verify(self, signature: bytes, data: bytes, algorithm: str) -> bytes:
        return hmac.compare_digest(
            signature,
            self.sign(data, algorithm)
        )

    def __bytes__(self) -> bytes:
        return self._secret