"""Declares :class:`ProviderSigningTestCase`."""
import inspect
import os

import pytest

import ckms


class ProviderSigningTestCase:
    """A test case that tests the signing and verification operations
    for a given provider.
    """
    data: bytes = b"Hello world!"

    @pytest.mark.asyncio
    async def test_sign(
        self,
        keychain: ckms.Keychain,
        data: bytes,
        using: str,
        algorithm: str
    ):
        sig = keychain.sign(data, using, algorithm)
        if inspect.isawaitable(sig):
            sig = await sig
        assert isinstance(sig, bytes)

    @pytest.mark.asyncio
    async def test_sign_and_verify(
        self,
        keychain: ckms.Keychain,
        data: bytes,
        using: str,
        algorithm: str
    ):
        sig = keychain.sign(data, using, algorithm)
        if inspect.isawaitable(sig):
            sig = await sig
        assert await keychain.verify(
            signature=sig,
            data=data,
            algorithm=algorithm,
            using=using
        )


    @pytest.mark.asyncio
    async def test_sign_and_verify_invalid_data(
        self,
        keychain: ckms.Keychain,
        data: bytes,
        using: str,
        algorithm: str
    ):
        sig = keychain.sign(data, using, algorithm)
        if inspect.isawaitable(sig):
            sig = await sig
        assert not await keychain.verify(
            signature=sig,
            data=os.urandom(len(data)),
            algorithm=algorithm,
            using=using
        )

    @pytest.mark.asyncio
    async def test_sign_and_verify_invalid_signature(
        self,
        keychain: ckms.Keychain,
        data: bytes,
        using: str,
        algorithm: str
    ):
        sig = keychain.sign(data, using, algorithm)
        if inspect.isawaitable(sig):
            sig = await sig
        assert not await keychain.verify(
            signature=os.urandom(len(sig)),
            data=data,
            algorithm=algorithm,
            using=using
        )