# pylint: skip-file
import pytest

from ckms.core.models import KeySpecification
from ckms.core.types import KeyOperationType


@pytest.mark.parametrize("kty", ["oct", "EC", "OKP", "RSA"])
def test_can_encrypt(kty: str):
    k = KeySpecification(provider="none", kty=kty, use=KeyOperationType.encrypt)
    assert k.can_encrypt()
    assert not k.can_sign()


@pytest.mark.parametrize("kty", ["oct", "EC", "OKP", "RSA"])
def test_can_sign(kty: str):
    k = KeySpecification(provider="none", kty=kty, use=KeyOperationType.sign)
    assert not k.can_encrypt()
    assert k.can_sign()


@pytest.mark.parametrize("kty,is_asymmetric", [
    ("oct", False),
    ("EC", True),
    ("OKP", True),
    ("RSA", True)
])
def test_is_asymmetric(kty: str, is_asymmetric: bool):
    k = KeySpecification(provider="none", kty=kty, use=KeyOperationType.sign)
    assert k.is_asymmetric() is is_asymmetric
    assert k.is_symmetric() is not is_asymmetric


@pytest.mark.parametrize("kty,is_symmetric", [
    ("oct", True),
    ("EC", False),
    ("OKP", False),
    ("RSA", False)
])
def test_is_symmetric(kty: str, is_symmetric: bool):
    k = KeySpecification(provider="none", kty=kty, use=KeyOperationType.sign)
    assert k.is_symmetric() is is_symmetric
    assert k.is_asymmetric() is not is_symmetric