# pylint: skip-file
import os

import pytest
from cryptography.hazmat.primitives.serialization import load_pem_private_key

import ckms


SUPPORTED_SIGNING_ALGORITHMS = [
	('rsa', 'RS256'),
	('rsa', 'RS384'),
	('rsa', 'RS512'),
	('rsa', 'PS256'),
	('rsa', 'PS384'),
	('rsa', 'PS512'),
	('p256', 'ES256'),
	('p384', 'ES384'),
	('p521', 'ES512'),
	('p256k', 'ES256K'),
	('hmac', 'HS256'),
	('hmac', 'HS384'),
	('hmac', 'HS512'),
	('ed448', 'EdDSA'),
	('ed25519', 'EdDSA'),
]


@pytest.fixture(scope='session')
def keychain():
    return ckms.Keychain()


@pytest.fixture(scope='session')
def keyconfig():
    return {
        'rsa': {
            'provider': "local",
            'path': "pki/rsa.key"
        },
        'p256': {
            'provider': "local",
            'path': "pki/p256.key"
        },
        'p384': {
            'provider': "local",
            'path': "pki/p384.key"
        },
        'p521': {
            'provider': "local",
            'path': "pki/p521.key"
        },
        'p256k': {
            'provider': "local",
            'path': "pki/p256k.key"
        },
        'ed448': {
            'provider': "local",
            'path': "pki/ed448.key"
        },
        'ed25519': {
            'provider': "local",
            'key': load_pem_private_key(open('pki/ed25519.key', 'rb').read(), None)
        },
        'rsa.public': {
            'provider': "local",
            'path': "pki/rsa.pub"
        },
        'hmac': {
            'provider': "local",
            'secret': os.urandom(64)
        },
        'aes128': {
            'provider': "local",
            'secret': os.urandom(16),
            'use': "enc"
        },
        'aes192': {
            'provider': "local",
            'secret': os.urandom(24),
            'use': "enc"
        },
        'aes256': {
            'provider': "local",
            'secret': os.urandom(32),
            'use': "enc"
        },
    }
