# pylint: skip-file
import pytest
from cryptography.hazmat.primitives.keywrap import aes_key_unwrap


@pytest.mark.parametrize("using,algorithm", [
    ('rsa', 'RSA1_5'),
    ('rsa', 'RSA-OAEP'),
    ('rsa', 'RSA-OAEP-256'),
    ('aes128', 'A128GCM'),
    ('aes192', 'A192GCM'),
    ('aes256', 'A256GCM'),
])
@pytest.mark.asyncio
async def test_encrypt(keychain, data, using, algorithm):
    ct = await keychain.encrypt(data, using, algorithm)
    pt = await keychain.decrypt(ct, using, algorithm)
    assert pt == data


@pytest.mark.parametrize("using,algorithm", [
    ('aes128', 'A128KW'),
    ('aes192', 'A192KW'),
    ('aes256', 'A256KW'),
])
@pytest.mark.asyncio
async def test_aes_key_wrap(keychain, data, using, algorithm):
    spec = keychain.get(using)
    ct = await keychain.encrypt(data, using, algorithm)
    pt = aes_key_unwrap(bytes(spec.key), ct)
    assert pt == data