# pylint: skip-file
import os

import httpx
import pytest
import pytest_asyncio

from ckms import jose


@pytest_asyncio.fixture(scope='session')
async def http():
    async with httpx.AsyncClient() as client:
        yield client


@pytest_asyncio.fixture(scope='session')
async def google_jwks(http):
    response = await http.get("https://accounts.google.com/.well-known/openid-configuration")
    metadata = response.json()
    response = await http.get(metadata['jwks_uri'])
    jwks = response.json()
    return {x['kid']: x for x in jwks['keys']}


@pytest.mark.asyncio
async def test_google_metadata_url(http):
    response = await http.get(
        url="https://accounts.google.com/.well-known/openid-configuration"
    )
    assert response.status_code == 200



@pytest.mark.asyncio
async def test_google_fromissuer(google_jwks):
    jwks = await jose.JSONWebKeySet.fromissuer("https://accounts.google.com")
    assert jwks.get_key_identifiers() == set(google_jwks.keys())


@pytest.mark.asyncio
async def test_nonexistant_dns_raises_issuerdoesnotexist():
    with pytest.raises(jose.exceptions.MisconfiguredIssuer):
        await jose.JSONWebKeySet.fromissuer(
            "https://{bytes.hex(os.urandom(32))}",
            silent=False
        )

@pytest.mark.asyncio
async def test_nonexisting_metadata_raises_oauthmetadatanotfound():
    with pytest.raises(jose.exceptions.MisconfiguredIssuer):
        await jose.JSONWebKeySet.fromissuer(
            "https://example.com",
            silent=False
        )
