# pylint: skip-file
import json

import authlib.jose.errors
import pytest
from authlib.jose import JsonWebSignature
from authlib.jose import JsonWebEncryption
from authlib.jose.errors import UnsupportedAlgorithmError

from .basecompatibility import BaseCompatibility


class TestCompatibility(BaseCompatibility):
    skip_algorithms: set = {
        "ES256K",
        "EdDSA",
        "RSA-OAEP-384",
        "RSA-OAEP-512",
        "A128GCMKW"
    }

    def decrypt_payload_compact(
        self,
        jwk: object,
        key: bytes,
        algorithm: str,
        encryption: str,
        payload: bytes
    ) -> tuple:
        jwe = JsonWebEncryption()
        data = jwe.deserialize_compact(payload, key)
        return data['header'], data['payload']

    def encrypt_payload_compact(
        self,
        jwk: 'JSONWebKey',
        key: bytes,
        algorithm: str,
        encryption: str,
        claims: dict,
        payload: bytes
    ) -> bytes:
        jwe = JsonWebEncryption()
        print(key.hex())
        return jwe.serialize_compact(claims, payload, key)

    def sign_compact(self, key: bytes, algorithm: str, kid: str, claims: dict) -> bytes:
        jws = JsonWebSignature()
        headers = {'kid': kid, 'alg': algorithm}
        return jws.serialize_compact(headers, json.dumps(claims), key)

    def verify_compact(self, key: bytes, token: bytes, algorithm: str):
        jws = JsonWebSignature()
        jws.deserialize_compact(token, key)
        return True