# pylint: skip-file
from jwcrypto.jwe import JWE
from jwcrypto.jwk import JWK
from jwcrypto.jwt import JWT
from jwcrypto.common import json_encode

from ckms.utils import b64encode
from .basecompatibility import BaseCompatibility


class TestCompatibility(BaseCompatibility):
    skip_algorithms = {
        "RSA1_5",
        "RSA-OAEP-384",
        "RSA-OAEP-512",
        "A128GCMKW"
    }

    def get_jwk(self, algorithm, key):
        if algorithm not in {"HS256", "HS384", "HS512"}:
            jwk = JWK.from_pem(key)
        else:
            jwk = JWK(kty="oct", k=bytes.decode(b64encode(key), "ascii"))
        return jwk

    def sign_compact(self, key: bytes, algorithm: str, kid: str, claims: dict) -> bytes:
        jwk = self.get_jwk(algorithm, key)
        jwt = JWT(
            claims=claims,
            header={
                'alg': algorithm,
                'kid': kid
            }
        )
        jwt.make_signed_token(jwk)
        return jwt.serialize(compact=True)

    def decrypt_payload_compact(
        self,
        jwk: object,
        key: bytes,
        algorithm: str,
        encryption: str,
        payload: bytes
    ) -> tuple:
        key = JWK(**jwk.dict(exclude_defaults=True))
        jwe = JWE()
        jwe.deserialize(payload.decode("utf-8"))
        jwe.decrypt(key)
        return None, None

    def encrypt_payload_compact(
        self,
        jwk: 'JSONWebKey',
        key: bytes,
        algorithm: str,
        encryption: str,
        claims: dict,
        payload: bytes
    ) -> bytes:
        key = JWK(**jwk.dict(exclude_defaults=True))
        jwe = JWE(
            payload,
            json_encode({
                **claims,
                'alg': algorithm,
                'enc': encryption
            })
        )
        jwe.add_recipient(key)
        return str.encode(jwe.serialize(compact=True), "ascii")

    def verify_compact(self, key: bytes, token: bytes, algorithm: str):
        jwk = self.get_jwk(algorithm, key)
        jwt = JWT()
        jwt.deserialize(bytes.decode(token), key=jwk)
        return True