# pylint: skip-file
from jose import jwt
from jose import jwe

from .basecompatibility import BaseCompatibility


class TestCompatibility(BaseCompatibility):
    skip_algorithms: set = {
        "PS256",
        "PS384",
        "PS512",
        "ES256K",
        "EdDSA",
        "RSA-OAEP-384",
        "RSA-OAEP-512",
        "A128GCMKW"
    }

    def decrypt_payload_compact(
        self,
        jwk: object,
        key: bytes,
        algorithm: str,
        encryption: str,
        payload: bytes
    ) -> tuple:
        return (
            jwe.get_unverified_header(payload),
            jwe.decrypt(payload, key)
        )

    def encrypt_payload_compact(
        self,
        jwk: 'JSONWebKey',
        key: bytes,
        algorithm: str,
        encryption: str,
        claims: dict,
        payload: bytes
    ) -> bytes:
        return jwe.encrypt(
            payload,
            algorithm=algorithm,
            encryption=encryption,
            key=key,
            kid=claims['kid']
        )

    def sign_compact(self, key: bytes, algorithm: str, kid: str, claims: dict) -> bytes:
        return jwt.encode(claims, key, algorithm=algorithm, headers={'kid': kid})

    def verify_compact(self, key: bytes, token: bytes, algorithm: str):
        jwt.decode(token, key, algorithms=[algorithm])
        return True