# pylint: skip-file
from ckms.algorithms import algorithm
import pytest

from ckms.jose import PayloadCodec
from ckms.jose import JSONWebToken
from ckms.jose import JOSEDeserializer
from ckms.jose import exceptions


def test_non_token_raises_malformed(serializer: JOSEDeserializer):
    with pytest.raises(exceptions.MalformedToken):
        serializer.deserialize_compact(b'foo')


def test_invalid_segments_raises_malformed(serializer):
    """Compact token is 3 or 5 segments."""
    with pytest.raises(exceptions.MalformedToken):
        serializer.deserialize_compact(b'foo.bar')

    with pytest.raises(exceptions.MalformedToken):
        serializer.deserialize_compact(b'foo.bar.baz.taz')

    with pytest.raises(exceptions.MalformedToken):
        serializer.deserialize_compact(b'foo.bar.baz.taz.foo.bar')


@pytest.mark.asyncio
async def test_missing_key_raises_unverifieable(keychain, codec):
    other = PayloadCodec()
    payload = codec.encode(JSONWebToken(foo=1))
    jws = await payload.sign(algorithm='RS256', using='rsa')
    with pytest.raises(exceptions.Unverifiable):
        jwt = await other.decode(bytes(jws))


@pytest.mark.asyncio
async def test_invalid_signature_raises_invalidsignature(keychain, codec):
    payload = codec.encode(JSONWebToken(foo=1))
    jws = await payload.sign(algorithm='RS256', using='rsa')
    with pytest.raises(exceptions.InvalidSignature):
        jwt = await codec.decode(bytes(jws)[:-2])