# pylint: skip-file
import json
import pytest

from ckms.jose.joseheader import JOSEHeader
from ckms.jose import exceptions
from ckms.utils import b64encode


def test_malformed_header_raises():
    with pytest.raises(exceptions.MalformedHeader):
        JOSEHeader.fromb64(b'f')

def test_missing_alg_raises():
    with pytest.raises(exceptions.InvalidHeader):
        header = json.dumps({}).encode('utf-8')
        JOSEHeader.fromb64(b64encode(header))


def test_crit_is_cast_to_set():
    header = json.dumps({'alg': 'HS256', 'crit': ['foo']}).encode('utf-8')
    jose = JOSEHeader.fromb64(b64encode(header))
    assert isinstance(jose.crit, set)
    assert jose.crit == {"foo"}


def test_unsupported_signing_algorithm_raises():
    with pytest.raises(exceptions.UnsupportedAlgorithm):
        jose = JOSEHeader.fromdict({'alg': "foo"})


def test_unsupported_encryption_algorithm_raises():
    with pytest.raises(exceptions.UnsupportedEncryption):
        jose = JOSEHeader.fromdict({'alg': "RSA-OAEP", "enc": "foo"})
