# pylint: skip-file
import pytest

from ckms.jose import ClaimSet
from ckms.jose import JSONWebSignature


@pytest.mark.asyncio
async def test_jws_sign_raw_payload(keychain, payload):
	jws = JSONWebSignature.frompayload(payload=payload)
	await jws.sign(
		keychain=keychain,
		algorithm='EdDSA',
		using='ed448'
	)
	assert jws.is_signed()
	assert await jws.verify(keychain)


@pytest.mark.asyncio
async def test_jws_get_claimset(encoded_jwt, jwt):
	jws = JSONWebSignature.parse(encoded_jwt)
	claims = jws.get_claimset()
	for k in jwt.claims.keys():
		assert getattr(claims, k, claims.extra.get(k)) is not None