# pylint: skip-file
import json

import pytest

from ckms import jose
from ckms.utils import b64encode
from .conftest import SIGNING_KEYS


@pytest.mark.parametrize("using,algorithm", SIGNING_KEYS)
@pytest.mark.asyncio
async def test_sign_with_protected_no_unprotected(keychain, payload, using, algorithm):
    protected = b64encode(str.encode(json.dumps({'alg': algorithm, 'kid': using})))
    sig = await jose.Signature.create(
        keychain=keychain,
        algorithm=algorithm,
        using=using,
        payload=payload,
        protected=protected
    )
    assert await keychain.verify(
        signature=bytes(sig),
        data=bytes(sig._protected) + b'.' + payload,
        using=using,
        algorithm=algorithm
    )
    assert await sig.verify(
        keychain=keychain,
        payload=payload,
    )
