# pylint: skip-file
"""Test the registration and lookup of provider implementations."""
from ckms import keychain
import pytest

import ckms
from ckms import providers

from .conftest import NullProvider


@pytest.mark.parametrize("name,params", [
    ('ed448', {'provider': 'local', 'kty': 'OKP', 'crv': 'Ed448'}),
    ('ed25519', {'provider': 'local', 'kty': 'OKP', 'crv': 'Ed25519'}),
    ('x448', {'provider': 'local', 'kty': 'OKP', 'crv': 'X448'}),
    ('x25519', {'provider': 'local', 'kty': 'OKP', 'crv': 'X25519'}),
    ('rsa2048', {'provider': 'local', 'kty': 'RSA', 'bit_length': 2048}),
    ('p256', {'provider': 'local', 'kty': 'EC', 'crv': 'P-256'}),
    ('p384', {'provider': 'local', 'kty': 'EC', 'crv': 'P-384'}),
    ('p521', {'provider': 'local', 'kty': 'EC', 'crv': 'P-521'}),
    ('p256k', {'provider': 'local', 'kty': 'EC', 'crv': 'P-256K'}),
    ('a128', {'provider': 'local', 'kty': 'oct', 'length': 16}),
    ('a192', {'provider': 'local', 'kty': 'oct', 'length': 24}),
    ('a256', {'provider': 'local', 'kty': 'oct', 'length': 32}),
])
@pytest.mark.asyncio
async def test_register_generate(name, params):
    keychain = ckms.Keychain()
    keychain.register({name: params})
    await keychain.setup()


def test_null_is_registered():
    p = providers.get('null')
    assert isinstance(p, NullProvider)


def test_register_with_parameters():
    providers.register(
        'nullwithparams',
        f'{NullProvider.__module__}:{NullProvider.__qualname__}',
        param='bar'
    )
    p = providers.get('nullwithparams')
    assert isinstance(p, NullProvider)
    assert p.param == 'bar'
    

def test_get_with_parameters():
    p = providers.get('null', param='baz')
    assert isinstance(p, NullProvider)
    assert p.param == 'baz'


def test_register_override_initial_params():
    providers.register(
        'nullwithparams',
        f'{NullProvider.__module__}:{NullProvider.__qualname__}',
        param='bar'
    )
    p = providers.get('nullwithparams', param='baz')
    assert isinstance(p, NullProvider)
    assert p.param == 'baz'
